#
# spec file for package tvbrowser
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           tvbrowser
Version:        4.2.7
Release:        bp155.1.11
Summary:        Digital TV guide
License:        GPL-3.0-or-later
Group:          Productivity/Multimedia/Other
URL:            https://tv-browser.org/
Source0:        https://downloads.sourceforge.net/project/tvbrowser/TV-Browser%20Releases%20%28Java%2011%20and%20higher%29/%{version}/%{name}_%{version}_src.zip
# TODO build from source, too
Source2:        https://www.tvbrowser.org/data/uploads/1372016422809_543/NewsPlugin.jar
Patch0:         fix-junit-classpath.patch
BuildRequires:  ant
BuildRequires:  ant-junit
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  java-devel >= 11
BuildRequires:  jpackage-utils
BuildRequires:  optipng
BuildRequires:  strip-nondeterminism
BuildRequires:  unzip
BuildRequires:  update-desktop-files
Requires:       java >= 11
BuildArch:      noarch

%description
TV-Browser is Plugin based digital TV guide. Plugins can be installed with
the download function of TV-Browser.

%prep
cp -p %{SOURCE2} .
%setup -q
# needed to apply patch
dos2unix build.xml
%patch0 -p1
dos2unix src/LICENSE.txt
find -name "*.png" | while read a; do
    optipng -quiet -o 5 "$a" || optipng -quiet -o 5 -fix "$a"
done

%build
%{ant} runtime-linux -Dnewsplugin.url=file:///%{_sourcedir}/NewsPlugin.jar
strip-nondeterminism runtime/tvbrowser_linux/icons/*.zip \
                     runtime/tvbrowser_linux/infothemes/*.zip \
                     runtime/tvbrowser_linux/*.jar

cat >tvbrowser <<'EOF'
#!/bin/sh
cd %{_javadir}/%{name}
exec ./tvbrowser.sh -Dswing.aatext=TRUE -Dawt.useSystemAAFontSettings=on "$@"
EOF

%install
export NO_BRP_CHECK_BYTECODE_VERSION="true"

install -D -p -m 0755 -t %{buildroot}%{_bindir}/ tvbrowser
install -D -m 0644 -t %{buildroot}%{_datadir}/metainfo/ deployment/linux/tvbrowser.appdata.xml

mkdir -p %{buildroot}%{_javadir}/%{name}/
cp -a runtime/tvbrowser_linux/* %{buildroot}%{_javadir}/%{name}/
chmod 0755 %{buildroot}%{_javadir}/%{name}/tvbrowser.sh

for size in 16 32 48 128; do
    (
        install -d %{buildroot}%{_datadir}/icons/hicolor/${size}x${size}/apps/
        cd %{buildroot}%{_datadir}/icons/hicolor/${size}x${size}/apps/
        ln -s %{_javadir}/%{name}/imgs/tvbrowser${size}.png tvbrowser.png
    )
done

%suse_update_desktop_file -c tvbrowser TV-Browser 'Digital TV Guide' tvbrowser tvbrowser Video AudioVideo TV

%fdupes %{buildroot}%{_javadir}

%check
# These test(s) fail:
rm -v test/src/util/misc/TextLineBreakerTest.java
%{ant} test

%files
%doc ChangeLog.txt
%{_bindir}/tvbrowser
%{_javadir}/%{name}
%{_datadir}/applications/tvbrowser.desktop
%{_datadir}/icons/hicolor/*/apps/tvbrowser.png
%{_datadir}/metainfo/tvbrowser.appdata.xml

%changelog
* Wed Jan  4 2023 thod_@gmx.de
- update to version 4.2.7
  * Several bug fixes, see https://sourceforge.net/p/tvbrowser/tvb/search/?q=%%28%%28ticket_num%%3A%%5B240+TO+263%%5D%%29+AND+%%28status%%3Aclosed%%29%%29
* Wed May 11 2022 wbauer@tmo.at
- update to version 4.2.6
  * Filter highlighting not saved
  * Import directory of version is questioned before selecting of
    import directory for transportable version
  * Reminders are not imported
* Sun May  8 2022 wbauer@tmo.at
- update to version 4.2.5
  * Easier building of FormLayouts
  * Allow multiple entries for exclusions in Favorites
  * Layout improvements
  * Use height instead of width for time buttons spread
  * Disabled context menu items should not be shown in program info
  * Allow disabling of sub sub context menu entries
  * Always use newest instance of program to show in ProgramInfo
  * Reminders not updated after data update
  * Add option to show info when test version of TV-Browser is available
  * Show info when using outdated TV-Browser version
  * Unify handling of properties for all type of plugins, add automated
    backup
  * Allow creation of new filter in filter selection panel
  * Add option to highlight programs of filter
  * Add option to show plugin actions in context menu of tabs and toolbar
    buttons
  * Easier access for editing filter components
  * Add option to not show download dialog again in the running session
  * Linkify additional plugin program infos
  * Possible NPE at creating program text for additional plugin infos
  * Transportable version doesn't find import directory under Linux
  * Order settings in groups
  * Last line of description missing
* Wed Dec 22 2021 wbauer@tmo.at
- update to version 4.2.4
  * Add support for ARM 64 CPU under macOS
  * High CPU load after installing plugins
  * support native full screen mode under macOS for restoring after
    startup
  * support OpenJDK usage for transportable version under macOS
  * Don't count programs more than once in Favorite tree
  * High CPU load when showing current reminders
  * Small naming improvements
  * GUI drawing problems after deleting certain plugins
  * Add import of Android Favorites definitions
  * Ask plugin before saving settings or data
  * Add option to highlight channels in programtable by mouse entering
    channel label
  * CCME in ReminderList
  * Episode title too dark in program info for dark background colors
  * High CPU usage while displaying reminder list
  * Add method to get filter by name for FilterManager
  * Provide panel for selection of filter
  * Add maximum wait time for closing TV-Browser during running
    data update
  * Possible exception during data update
  * NPE when filter file is broken
  * Add warning if Acronis True Image is used on system
  * Other plugins should be able to request deleting of Reminder
  * Reminder and Favorites cannot receive programs
  * Season number parameter causes Exception
* Thu Jul  1 2021 wbauer@tmo.at
- update to version 4.2.3
  * Menu item to open settings directory
  * Show progress during downloading plugins
  * Inform plugins when TV-Browser version was updated
  * Add function to replace new line characters with single white space
  * Add function to escape quotes in parameter handler
  * Escaped quotes are not recognized when building command line
    parameters for executing external processes
  * Add escape charactar to string sequences in parameter library
  * Show info to user if plugin file is outside of user space on deleting
  * Show channel configuration only if data plugins are installed
  * Config assistant freezes TV-Browser if no data plugin is installed
  * Add autostart option for Linux
  * Plugins can return information about a program
  * Better display of additional persons in info dialog
  * Allow reset of plugin settings handled by TV-Browser
  * Show info if restart is needed to apply changes
  * Show genric filter info for context menu settings
  * Duration exclusion not saved
  * Only add date separators visibly to program list
  * Global Favorite exclusions disappear after restart of TV-Browser
  * Add tvb:// protocol handling
  * Description not always printed in program table
- Update NewsPlugin to 3.1.8.0
* Sun Dec 27 2020 wbauer@tmo.at
- update to version 4.2.2
  * ProgramList contains unneeded gaps
  * On air status of program not refreshed under certain conditions
  * Add free text filter to plugin settings tab
  * Add option to prefilter showing of Reminders
  * Add option to pause reminder for time range
  * Already removed reminders reappear after data update
  * Add history to settings dialog
  * Allow highlighting with gradient colors
  * Add auto update option only for prime time
  * TV-Browser doesn't start with _JAVA_OPTIONS set
  * Allow easy exclusion of programs from Favorite based on
    duration
  * Crash under macOS
  * flexibilize parameter handler
  * Possible NPE if filter files are broken
  * Add default filter for live programs
  * Add free text filter to plugin download dialog
  * Show exclusions to user when newly created favorite doesn't
    find program it was based on
  * Add option to select/handle type of send programs to plugins
  * Provide menu to delete all reminders with certain conditions
  * Allow plugins to inject ActionMenu into context menu for
    programs requested by plugin
  * Ask user periodically for deletion of old versions settings files
  * Ask user for import directory if more than one was recently
    used
  * Plugins cannot delete own filters
  * Allow more highlighting colors
  * High CPU usage under certain conditions
  * Settings export goes to wrong directory with Linux OS
- Update NewsPlugin to 3.1.7.0
* Tue Dec 15 2020 wbauer@tmo.at
- update to version 4.2.1
  * Make sure plugins are informed about TV-Browser started event
    before starting auto update
  * Registry values can not be set under Windows
  * Allow copying of removed/added channels to clipboard
  * Tray popup at wrong location on scaled displays
  * Allow plugins to get context menu item of single plugin
  * multiple mark priority settings only return mark priority of
    first item
  * follow XDG Base Directory Specification on Linux systems
  * TV-Browser is not starting up in some cases
  * Program count missing in plugin tree
* Mon Sep 30 2019 munix9@googlemail.com
- update to version 4.2
  - Check if TV-Browser window is below task bar
  - Divider position not remembered for Favorite tab
  - use earliest reminder time for multiple reminders of program
  - Option for alternative info display for program panels based on filter
  - Add update function for TV-Browser JRE
  - Smaller setting design improvements
  - Program table not painted correctly on high resolution screens
  - add option to duplicate filters and filter components
  - Open TV-Browser on last used screen
  - Allow smoother scrolling in lists with programs
  - graphical errors while scrolling plugin installation list with touch pad
  - make TV-Browser Java 11 based
  - Add panning support
  - Add compounded field for origin and production year fields
  - Close in dual start warning not working
  - Picture copyright is not searchable
- Add patch fix-junit-classpath.patch
* Mon Apr 22 2019 munix9@googlemail.com
- update to version 4.0.1
  - Prevent pictures from growing in height too much
  - Programs are not updated in frame with reminders
  - Make start menu entries for Windows optional
  - Autoresize reminder window
  - Add system wide key shortcuts
  - Date selection is not update if calendar is used
  - Update launch4j itself and configuration
  - TV Browser - Java 9 - Windows doesn't start.
  - Center weekday labels in date selection table
  - Filter edit in Favorites resets selected filter
  - Allow to research all Favorite programs
  - Show reminders time sorted when shown together
* Mon Sep 25 2017 ecsos@opensuse.org
- update to version 4
  - Pos1 jumps mostly to the end of a program list
  - TV-Browser freezes at startup
  - Filter components wrongly added
  - Allow disabling of plugin sub menu items in context menu of program
  - Better focus handling for tabs in main frame
  - Context menu entry for setup of plugin in tabs
  - Show icons in tabs
  - Allow setup of line spacing for program panel font setting
  - Show channel groups in filterable program panel filter selection
  - Add option to show new found Favorite programs
  - Allow disabling of short description in ProgramInfo
  - Keyboard shortcuts for plugin actions should also work in fullscreen mode
  - Allow plugins to show more than one context menu action directly in context menu
  - Toolbar button for showing of menu
  - Allow displaying of original title if available
  - Function to highlight channel in program table that is scrolled to
  - Cancel search when search result dialog is closed
  - Longer pre data update waiting time
  - Allow deletion of single entries of search history
  - Colored backgrounds for channel label
  - Add easy copying of links
  - Use same logic for user defined font
  - Option to select more than 1 mouse action for plugin
  - Option to default to horizontal scroll in program table
  - Better reminder dialog
  - More exclusion options for Favorites
  - Wrong text for FAYT filter
  - Allow setup of reminder minutes for Favorites
  - AppData.xml file for Linux software stores
  - .deb package: symbolic link to init-script doesnt work
  - Time zone normalization might miss daylight savings time
  - Possible NPE in creation of tray programs menu
- Update NewsPlugin to 3.1.4.0
- Raise Java dependencies to 1.8
- Drop tvbrowser.appdata.xml and install the file included in the
  source tarball
- increase java heap space
* Fri Apr 21 2017 bwiedemann@suse.com
- use strip-nondeterminism to make build fully reproducible
* Sun Nov 20 2016 mailaender@opensuse.org
- add appdata.xml for https://en.opensuse.org/openSUSE:AppStore
- enable unit tests (except 2 broken ones)
* Wed Jun 29 2016 dl8fcl@darc.de
- Update to version 3.4.4
- Allow deletion/reminder change for multiple favorites
- Make first day of week configurable
- Allow usage of filter to determine picture showing
- Preselect channels based on user country/language
- Prevent buttons in ConfiAssistant to be hidden
- Add whole term search as search option
- Allow separators in channel list
- Mark filters as broken if it contains broken filter components
- Single channel filter lost at removing of channel
- Plugin selection for picture settings mostly empty
- Provide restart after changing of plugin picture settings
- Allow plugins to add additional information to programs
- Allow different download ranges for manual and automatic update
- Allow deletion of data plugins from context menu
- Add auto update to channel list with user info
* Mon Jan  4 2016 dl8fcl@t-online.de
- Update to version 3.4.3
  fixes a critical bug of the previous version
* Fri Dec 25 2015 dl8fcl@t-online.de
- Update to version 3.4.2
- Allow to show program table icons with text in tool tip
- User should be able to select order of data postprocessing
- Allow change of visibility of progress bar in ProgressMonitor
- Allow access to progress monitor from PluginManager
- Identify label of persons in program info
- Allow plugins to set indeterminated state of progress bar
- Fix GTK+ theme with never Java
- Add parameter for channel sort number
- Allow export/import of channels
- Filter favorite ignores filter on data update
- Command line parameter not forwared for Linux packages
- Allow origin in parameter library
- Allow channel synchronization with Android
- Wrong codepage for theme downloads
- Weekdays switched in weekday filter component
- Favorites not save after sorting
- tooltip wrong in program list
- Search hint not deleted if search value inserted from clipboard
* Wed Dec 24 2014 dl8fcl@darc.de
- Update to version 3.4.1
- Only now and next programs in tray use filter settings value
- Allow instant advanced search for repetition search
- Make download handling more safe for not reacting servers (use threaded timeouts)
- Use at least picture with if available for picture display
- Speed up date change for program table
- Missing ProgramReceiceIfs are causing problems
- Create backup files for plugin data
- Better search for running and next program in tray
- Show channel logo in program panels
- Show restart entry in tray and after changing of locale
- Speed up marking
- Allow plugins to disable artificial plugin tree
- Create new favorite type for direct usage of filters
- Add fallback to auto download of plugin list
- Favorite exclusion window too small
- FilterManager should also handle ChannelGroups
- Show sort number in reminder and tray
- Internet connection check may have threading problem
- Add alphabetically sort function to filter tree
- Allow easy creation of channel filter
* Sat Sep 13 2014 ecsos@schirra.net
- Update to version 3.4.0.1
  Fix for TV-Browser might not start because of a configuration fault
  in the change of the channel charing of Comedy Central (de),
  VIVA (de) and Nickelodeon (de).
* Wed Jul  2 2014 dl8fcl@darc.de
- Update to version 3.4
  This version brings many new features that were often suggested like
  showing of program numbers or yers on our to do list. TV-Browser 3.4
  makes it easy to install new icon themes directly in TV-Browser.
  The Favorites can be viewed filtered and can be created as filter themself.
  TV-Browser 3.4 also fixes bugs so it will run even better than the
  previous version. We suggest to update to TV-Browser 3.4 as soon
  as possible, to profit from the new features an bug fixes.
- New Feature: Allow exclusions from favorites depending on the program category
- New Feature: Let plugins request to be click action plugin
- New Feature: detect configuration changes and reload settings
- New Feature: have generic filter possibility for plugin markers
- New Feature: "Add own URL-Handler for ""tvbrowser://"" - Links "
- New Feature: "New program fields ""part number"" and ""part total number"" "
- New Feature: Make display of data in program table customizable
- New Feature: have menu item to create a debug log
- New Feature: show warning for useless search option combination
- Improvement: Allow user to create filter for single Favorite
- Improvement: Provide way for plugins to communicate with each other in an
    indirect and save way
- Improvement: Allow filter usage in Favorite tab/dialog
- Improvement: Use time buttons for navigation in tab
- Improvement: Store paths relative if possible
- Improvement: show no warning for self-deleted data files
- Improvement: Store window position of reminder window
- Improvement: Don't remove channels automatically if they aren't available
- Improvement: have different additional info icon sets or allow changing those
    icons easily
- Improvement: Show Info when no channels are displayed
- Improvement: Redesign search dialog to make it more easy to use
- Bug: ConcurrentModificationException while update of TV Browser data
- Bug: Wrong default reminder time causes exception at opening settings
- Bug: Internet connection check dialog not removed for update started after
    startup
- Bug: Found favorites window opens with empty favorites
- Bug: ArrayIndexOutOfBoundsException whenn adding programs to ProgramList
- Bug: Timezone correction doesn't work properly in countries with different
    daylight saving time than the channel's country
- Bug: No more updates possible for a channelgroup when all mirrors changed
    since the last update
- Bug: empty plugin tree for some plugins if tvb started with closed plugin
    tree view
- Bug: Background color of currently running programs is displayed false
- Bug: Program data files are not treated if the next 7 days none of them exists
* Sat Feb  8 2014 mailaender@opensuse.org
- actually build from source
* Thu Nov 21 2013 dl8fcl@darc.de
- Update to version 3.3.3
- Make pictures of expired program darker not gray
- Show list of available plugins sorted alphabetically
- Allow plugins to prepare for data update
- Allow more than one episode number in field value (encoded)
- Plugins should be able to set custom program field type name.
- Highlight programs that run at time scroll time
- Plugin autoupdate is not shown
- Reminder recreated on favorite programs after update
- Make programs easy accessible that start at the same time on the
  same channel on the same date
- NPE in day selection calendar under Mac OS X
- Add warning if user deactiavtes the program table tab
- Original ProgramReceiveTargets are sorted by TV-Browser
- AIOOBE in ProgramList
- Filter changes should be trackable for plugins
- Date range for auto update changes with user initiated update
- Allow programs with duplicate start times
- option to enable/disable/configure highlighting of mouse menu colors
- Webpages in Plugin-Install-Dialog should be clickable
- Scroll to now after download (if there was no data available before)
- ask for minimize to tray on first close
* Mon Sep  2 2013 dl8fcl@darc.de
- Update to version 3.3.2
- Allow filter usage in search dialog
- Scroll automatically to next/previous day when mouse wheel is
  used in program table
* Thu Jul 18 2013 dl8fcl@darc.de
- Update to version 3.3.1
- Centralize mouse actions and make it more customizable
- Make filter editable from edit favorite dialog
- Search accepts German UND, ODER
- Description in FilterComponent classes, removed from settings panel
- Browsing with keyboard in filter-list
- Ability to remind after program start
* Sat Mar 23 2013 dl8fcl@darc.de
- Update to version 3.3
- new languages, Croatian and Greek. It is possible to install
  additional languages in the program settings.
- Date separators added for better orientation in the program lists
  of the plugins.
* Mon Oct 29 2012 meissner@suse.com
- use a URL for Source0.
* Sun Oct 28 2012 dl8fcl@darc.de
- Update to version 3.2.1
- TV-Browser 3.2.1 improves the performance, fixes some minor bugs
  and a mayor one that could destroy users filter components.
- TV-Browser 3.2 fixes bugs for better stability.
  New features are tab support, plugins can show their information
  the main window, many new predefined filters.
* Mon Dec  5 2011 gber@opensuse.org
- convert the included license to Unix line endings instead of
  shipping a separate copy of the license
- create a tailored launch script instead of relying on the
  guesswork in the upstream script and do not create symlinks
  bypassing the packaging system in %%post
- create desktop file via %%suse_update_desktop_file instead of
  patching the upstream one
- create explicit symlinks for application icons
- use %%desktop_database_post/un and %%icon_theme_cache_post/un to
  have the menu and icon caches updated on GTK-based desktops
- correct the RPM group
* Sun Oct 30 2011 dl8fcl@darc.de
- Update to version 3.1
* Fri Sep 16 2011 dl8fcl@darc.de 
- Update to version 3.0.2
- Description and LICENSE.txt updated
* Thu May 12 2011 dl8fcl@darc.de
- Update to version 3.0.1, tvbrowser-desktop fixed
* Sun Apr 11 2010 davejplater@gmail.com
- Update to version 2.7.5 added tvbrowser-2.7.5-desktop.patch
- TV-Browser 2.7.5 fixes one major and a few minor bugs.
  The major bug could prevent the german tv shows to be listed in
  the installation wizard.
- TV-Browser 2.7.4 fixes some bugs.
- TV-Browser 2.7.3 resolves mainly a bug in the data processing who
  led to an overload of the TV-Browser server at about 8 p.m.
  Additonally this update provides several minor bugfixes.
  We ask you emphatically to install TV-Browser 2.7.3 as soon as
  possible to decrease the load of the TV-Browser server.
* Thu Mar  5 2009 ro@suse.de
- added optipng to buildreq
* Sat Feb  7 2009 coolo@suse.de
- own the hicolor directories too
* Thu Jan 22 2009 tpatzig@suse.de
- update to version 2.7.2
  * new Java LookAndFeel Nimbus
  * stability and usabilty improvements
* Mon Mar  3 2008 tpatzig@suse.de
- update to version 2.6.3
  * a lot of Bugfixes
* Wed Nov 14 2007 tpatzig@suse.de
- update to version 2.6
  * Bugfixes
  * notification, when channels added or deleted
  * SMS/EMail notification via google calender
  * group your favorite tv-shows
  * automatic notifications for available plugin updates
  * new filter functionality
  * new settings
* Mon Aug  6 2007 tpatzig@suse.de
- added linux.properties
* Sat Aug  4 2007 tpatzig@suse.de
- fixed wrong permissions
* Sat Aug  4 2007 tpatzig@suse.de
- update to version 2.5.3
  * Bugfixes
  * automatically safe properties, when changed
  * automatic backup of the config file, to restore them if needed
* Tue Jul  3 2007 tpatzig@suse.de
- updated to version 2.5.2
- deleted libDesktopIndicator.so
* Mon Jan  8 2007 tpatzig@suse.de
- initial rpm build for TV-Browser 2.5
